/**
  **************************************************************************
  * @file     xmc_lcd_5510.c
  * @version  v2.0.0
  * @date     2020-11-02
  * @brief    xmc_lcd program file
  **************************************************************************
  *                       Copyright notice & Disclaimer
  *
  * The software Board Support Package (BSP) that is made available to 
  * download from Artery official website is the copyrighted work of Artery. 
  * Artery authorizes customers to use, copy, and distribute the BSP 
  * software and its related documentation for the purpose of design and 
  * development in conjunction with Artery microcontrollers. Use of the 
  * software is governed by this copyright notice and the following disclaimer.
  *
  * THIS SOFTWARE IS PROVIDED ON "AS IS" BASIS WITHOUT WARRANTIES,
  * GUARANTEES OR REPRESENTATIONS OF ANY KIND. ARTERY EXPRESSLY DISCLAIMS,
  * TO THE FULLEST EXTENT PERMITTED BY LAW, ALL EXPRESS, IMPLIED OR
  * STATUTORY OR OTHER WARRANTIES, GUARANTEES OR REPRESENTATIONS,
  * INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT.
  *
  **************************************************************************
  */
  
#include "xmc_lcd_5510.h"

_lcd_dev  lcd_dev = 
{
  0,
  xmc_init,
  LCD_init,
  LCD_SetBlock,
  LCD_DrawPoint,
  LCD_Clear,
};

_lcd_dev *lcd;

u32	lcd_dir=0;
u32	lcd_wramcmd=0;
u32	lcd_setxcmd=0;
u32	lcd_setycmd=0;
u32	lcd_width=0;
u32	lcd_height=0;


//LCDԶɨ淽
//dir:0~7,8(ͷļ)
void LCD_Set_Scan_Dir(u8 dir)
{
	uint16_t regval=0;
	uint16_t dirreg=0;
	uint16_t temp; 

  switch(dir)//ת
  {
    case 0:dir=6;break;
    case 1:dir=7;break;
    case 2:dir=4;break;
    case 3:dir=5;break;
    case 4:dir=1;break;
    case 5:dir=0;break;
    case 6:dir=3;break;
    case 7:dir=2;break;	     
  }
  
	switch(dir)
	{
		case L2R_U2D://,ϵ
			regval|=(0<<7)|(0<<6)|(0<<5); 
			break;
		case L2R_D2U://,µ
			regval|=(1<<7)|(0<<6)|(0<<5); 
			break;
		case R2L_U2D://ҵ,ϵ
			regval|=(0<<7)|(1<<6)|(0<<5); 
			break;
		case R2L_D2U://ҵ,µ
			regval|=(1<<7)|(1<<6)|(0<<5); 
			break;	 
		case U2D_L2R://ϵ,
			regval|=(0<<7)|(0<<6)|(1<<5); 
			break;
		case U2D_R2L://ϵ,ҵ
			regval|=(0<<7)|(1<<6)|(1<<5); 
			break;
		case D2U_L2R://µ,
			regval|=(1<<7)|(0<<6)|(1<<5); 
			break;
		case D2U_R2L://µ,ҵ
			regval|=(1<<7)|(1<<6)|(1<<5); 
			break;	 
	}
	dirreg=0X3600;
	LCD_WriteReg(dirreg,regval);
//  printf("regval=%x\r\n",regval);
	if(regval&0X20)
	{
		if(lcd_width<lcd_height)//X,Y
		{
			temp=lcd_width;
			lcd_width=lcd_height;
			lcd_height=temp;
		}
	}else  
	{
		if(lcd_width>lcd_height)//X,Y
		{
			temp=lcd_width;
			lcd_width=lcd_height;
			lcd_height=temp;
		}
	}  
	LCD_WR_COMMAND(lcd_setxcmd);//Ӧô
	LCD_WR_DATA(0);
	LCD_WR_COMMAND(lcd_setxcmd+1);
	LCD_WR_DATA(0);
	LCD_WR_COMMAND(lcd_setxcmd+2);
	LCD_WR_DATA((lcd_width-1)>>8);
	LCD_WR_COMMAND(lcd_setxcmd+3);
	LCD_WR_DATA((lcd_width-1)&0xFF);
	
	LCD_WR_COMMAND(lcd_setycmd);
	LCD_WR_DATA(0);
	LCD_WR_COMMAND(lcd_setycmd+1);
	LCD_WR_DATA(0);
	LCD_WR_COMMAND(lcd_setycmd+2);
	LCD_WR_DATA((lcd_height-1)>>8);
	LCD_WR_COMMAND(lcd_setycmd+3);
	LCD_WR_DATA((lcd_height-1)&0xFF);	
  
  
}
//LCDʾ
//dir:0    1 
void TFT_Set_Display_Dir(u8 dir)
{
	if(dir==0)
	{
		lcd_dir=0;
		lcd_wramcmd=0x2c00;
		lcd_setxcmd=0x2A00;
		lcd_setycmd=0x2B00;
		lcd_width=480;
		lcd_height=800;
	}
	else
	{
		lcd_dir=1;
		lcd_wramcmd=0x2c00;
		lcd_setxcmd=0x2A00;
		lcd_setycmd=0x2B00;
		lcd_width=800;
		lcd_height=480;
	}
	LCD_Set_Scan_Dir(DFT_SCAN_DIR);
}

//дĴ
//LCD_Reg:Ĵַ
//LCD_RegValue:Ҫд
void LCD_WriteReg(uint16_t LCD_Reg,uint16_t LCD_RegValue)
{	
  LCD_WR_COMMAND(LCD_Reg); 
  LCD_WR_DATA(LCD_RegValue);  
}

//ٻ
//x,y:
//color:ɫ
void LCD_Fast_DrawPoint(uint16_t x,uint16_t y,uint16_t color)
{
		LCD_WR_COMMAND(0X2A00);LCD_WR_DATA(x>>8);  
		LCD_WR_COMMAND(0X2A00+1);LCD_WR_DATA(x&0XFF);	  
		LCD_WR_COMMAND(0X2B00);LCD_WR_DATA(y>>8);  
		LCD_WR_COMMAND(0X2B00+1);LCD_WR_DATA(y&0XFF); 
    LCD_WR_COMMAND(0X2C00);
    LCD_WR_DATA(color);
}

/**
  * @brief  configures the xmc and gpios to interface with the lcd.
  *         this function must be called before any write/read operation
  *         on the lcd.
  * @param  none 
  * @retval none
  */
void xmc_init(void)
{
  gpio_init_type  gpio_init_struct = {0};
  xmc_norsram_init_type  xmc_norsram_init_struct;
  xmc_norsram_timing_init_type rw_timing_struct, w_timing_struct;
  
  /* enable the gpio clock */
  crm_periph_clock_enable(CRM_GPIOA_PERIPH_CLOCK, TRUE);
  crm_periph_clock_enable(CRM_GPIOB_PERIPH_CLOCK, TRUE);
  crm_periph_clock_enable(CRM_GPIOC_PERIPH_CLOCK, TRUE);
  crm_periph_clock_enable(CRM_GPIOD_PERIPH_CLOCK, TRUE);
  crm_periph_clock_enable(CRM_GPIOE_PERIPH_CLOCK, TRUE);
  crm_periph_clock_enable(CRM_IOMUX_PERIPH_CLOCK, TRUE);  
  /* enable the xmc clock */
  crm_periph_clock_enable(CRM_XMC_PERIPH_CLOCK, TRUE);
  
  gpio_pin_remap_config(XMC_NADV_GMUX,TRUE);
  gpio_pin_remap_config(XMC_GMUX_001,TRUE);


  /* lcd data lines configuration */
  gpio_init_struct.gpio_pins = GPIO_PINS_2 | GPIO_PINS_3 | GPIO_PINS_4 | GPIO_PINS_5;
  gpio_init_struct.gpio_mode = GPIO_MODE_MUX;
  gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOA, &gpio_init_struct);
  
  gpio_init_struct.gpio_pins = GPIO_PINS_12 | GPIO_PINS_14;
  gpio_init_struct.gpio_mode = GPIO_MODE_MUX;
  gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOB, &gpio_init_struct);
  
  gpio_init_struct.gpio_pins = GPIO_PINS_6 | GPIO_PINS_11 | GPIO_PINS_12;
  gpio_init_struct.gpio_mode = GPIO_MODE_MUX;
  gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOC, &gpio_init_struct);
  
  gpio_init_struct.gpio_pins = GPIO_PINS_11 | GPIO_PINS_12 | GPIO_PINS_13 | GPIO_PINS_14 | GPIO_PINS_15;
  gpio_init_struct.gpio_mode = GPIO_MODE_MUX;
  gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOE, &gpio_init_struct);
  
  gpio_init_struct.gpio_pins = GPIO_PINS_9 | GPIO_PINS_10;
  gpio_init_struct.gpio_mode = GPIO_MODE_MUX;
  gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOD, &gpio_init_struct);
  
  /* lcd reset lines configuration */
  gpio_init_struct.gpio_pins = GPIO_PINS_0;
  gpio_init_struct.gpio_mode = GPIO_MODE_OUTPUT;
  gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOB, &gpio_init_struct);
  
  gpio_init_struct.gpio_pins = GPIO_PINS_3;
  gpio_init_struct.gpio_mode = GPIO_MODE_OUTPUT;
  gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOD, &gpio_init_struct);
  
  /* lcd rs/cs/wr/rd lines configuration */
  gpio_init_struct.gpio_pins = GPIO_PINS_5;
  gpio_init_struct.gpio_mode = GPIO_MODE_MUX;
  gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOC, &gpio_init_struct);
  
  gpio_init_struct.gpio_pins = GPIO_PINS_2 | GPIO_PINS_11 | GPIO_PINS_7;
  gpio_init_struct.gpio_mode = GPIO_MODE_MUX;
  gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOD, &gpio_init_struct);

  /*-- xmc configuration ------------------------------------------------------*/
  xmc_norsram_default_para_init(&xmc_norsram_init_struct);
  xmc_norsram_init_struct.subbank = XMC_BANK1_NOR_SRAM1;
  xmc_norsram_init_struct.data_addr_multiplex = XMC_DATA_ADDR_MUX_DISABLE;
  xmc_norsram_init_struct.device = XMC_DEVICE_SRAM;
  xmc_norsram_init_struct.bus_type = XMC_BUSTYPE_16_BITS;
  xmc_norsram_init_struct.burst_mode_enable = XMC_BURST_MODE_DISABLE;
  xmc_norsram_init_struct.asynwait_enable = XMC_ASYN_WAIT_DISABLE;
  xmc_norsram_init_struct.wait_signal_lv = XMC_WAIT_SIGNAL_LEVEL_LOW;
  xmc_norsram_init_struct.wrapped_mode_enable = XMC_WRAPPED_MODE_DISABLE;
  xmc_norsram_init_struct.wait_signal_config = XMC_WAIT_SIGNAL_SYN_BEFORE;
  xmc_norsram_init_struct.write_enable = XMC_WRITE_OPERATION_ENABLE;
  xmc_norsram_init_struct.wait_signal_enable = XMC_WAIT_SIGNAL_DISABLE;
  xmc_norsram_init_struct.write_timing_enable = XMC_WRITE_TIMING_ENABLE;
  xmc_norsram_init_struct.write_burst_syn = XMC_WRITE_BURST_SYN_DISABLE;
  xmc_nor_sram_init(&xmc_norsram_init_struct);
  
  /* timing configuration */
  xmc_norsram_timing_default_para_init(&rw_timing_struct, &w_timing_struct);
  rw_timing_struct.subbank = XMC_BANK1_NOR_SRAM1;
  rw_timing_struct.write_timing_enable = XMC_WRITE_TIMING_ENABLE;
  rw_timing_struct.addr_setup_time = 0x2;
  rw_timing_struct.addr_hold_time = 0x0;
  rw_timing_struct.data_setup_time = 0x2;
  rw_timing_struct.bus_latency_time = 0x0;
  rw_timing_struct.clk_psc = 0x0;
  rw_timing_struct.data_latency_time = 0x0;
  rw_timing_struct.mode = XMC_ACCESS_MODE_A;
  w_timing_struct.subbank = XMC_BANK1_NOR_SRAM1;
  w_timing_struct.write_timing_enable = XMC_WRITE_TIMING_ENABLE;
  w_timing_struct.addr_setup_time = 0x2;
  w_timing_struct.addr_hold_time = 0x0;
  w_timing_struct.data_setup_time = 0x2;
  w_timing_struct.bus_latency_time = 0x0;
  w_timing_struct.clk_psc = 0x0;
  w_timing_struct.data_latency_time = 0x0;
  w_timing_struct.mode = XMC_ACCESS_MODE_A;  
  xmc_nor_sram_timing_config(&rw_timing_struct, &w_timing_struct);
  
  xmc_ext_timing_config(XMC_BANK1_NOR_SRAM1,0,0); 
  /* enable xmc_bank1_nor_sram1 */
  xmc_nor_sram_enable(XMC_BANK1_NOR_SRAM1, TRUE);
}


/**
  * @brief  Configures the LCD.
  *         This function must be called before any write/read operation
  *         on the LCD.
  * @param  None 
  * @retval None
  */
void LCD_init(void)
{
  /* Init XMC */
  xmc_init();
  LCD_RESET_HIGH;
  delay_ms(50);
  /* Read ID*/
  LCD_WR_COMMAND(0x0000);
  delay_ms(5);

  lcd->lcd_id = LCD_RD_DATA();
  LCD_WR_COMMAND(0XDA00);//0X00
  lcd->lcd_id = LCD_RD_DATA();
  LCD_WR_COMMAND(0XDB00);//0X80
  lcd->lcd_id = LCD_RD_DATA();
  lcd->lcd_id<<=8;

  LCD_WR_COMMAND(0XDC00);
  lcd->lcd_id |= LCD_RD_DATA(); //0X00	
        
  delay_ms(50);
  LCD_WriteReg(0x0000,0x0001); 
  delay_ms(50); 
  
  LCD_WriteReg(0xF000,0x55);
  LCD_WriteReg(0xF001,0xAA);
  LCD_WriteReg(0xF002,0x52);
  LCD_WriteReg(0xF003,0x08);
  LCD_WriteReg(0xF004,0x01);
  //AVDD Set AVDD 5.2V
  LCD_WriteReg(0xB000,0x0D);
  LCD_WriteReg(0xB001,0x0D);
  LCD_WriteReg(0xB002,0x0D);
  //AVDD ratio
  LCD_WriteReg(0xB600,0x34);
  LCD_WriteReg(0xB601,0x34);
  LCD_WriteReg(0xB602,0x34);
  //AVEE -5.2V
  LCD_WriteReg(0xB100,0x0D);
  LCD_WriteReg(0xB101,0x0D);
  LCD_WriteReg(0xB102,0x0D);
  //AVEE ratio
  LCD_WriteReg(0xB700,0x34);
  LCD_WriteReg(0xB701,0x34);
  LCD_WriteReg(0xB702,0x34);
  //VCL -2.5V
  LCD_WriteReg(0xB200,0x00);
  LCD_WriteReg(0xB201,0x00);
  LCD_WriteReg(0xB202,0x00);
  //VCL ratio
  LCD_WriteReg(0xB800,0x24);
  LCD_WriteReg(0xB801,0x24);
  LCD_WriteReg(0xB802,0x24);
  //VGH 15V (Free pump)
  LCD_WriteReg(0xBF00,0x01);
  LCD_WriteReg(0xB300,0x0F);
  LCD_WriteReg(0xB301,0x0F);
  LCD_WriteReg(0xB302,0x0F);
  //VGH ratio
  LCD_WriteReg(0xB900,0x34);
  LCD_WriteReg(0xB901,0x34);
  LCD_WriteReg(0xB902,0x34);
  //VGL_REG -10V
  LCD_WriteReg(0xB500,0x08);
  LCD_WriteReg(0xB501,0x08);
  LCD_WriteReg(0xB502,0x08);
  LCD_WriteReg(0xC200,0x03);
  //VGLX ratio
  LCD_WriteReg(0xBA00,0x24);
  LCD_WriteReg(0xBA01,0x24);
  LCD_WriteReg(0xBA02,0x24);
  //VGMP/VGSP 4.5V/0V
  LCD_WriteReg(0xBC00,0x00);
  LCD_WriteReg(0xBC01,0x78);
  LCD_WriteReg(0xBC02,0x00);
  //VGMN/VGSN -4.5V/0V
  LCD_WriteReg(0xBD00,0x00);
  LCD_WriteReg(0xBD01,0x78);
  LCD_WriteReg(0xBD02,0x00);
  //VCOM
  LCD_WriteReg(0xBE00,0x00);
  LCD_WriteReg(0xBE01,0x64);
  //Gamma Setting
  LCD_WriteReg(0xD100,0x00);
  LCD_WriteReg(0xD101,0x33);
  LCD_WriteReg(0xD102,0x00);
  LCD_WriteReg(0xD103,0x34);
  LCD_WriteReg(0xD104,0x00);
  LCD_WriteReg(0xD105,0x3A);
  LCD_WriteReg(0xD106,0x00);
  LCD_WriteReg(0xD107,0x4A);
  LCD_WriteReg(0xD108,0x00);
  LCD_WriteReg(0xD109,0x5C);
  LCD_WriteReg(0xD10A,0x00);
  LCD_WriteReg(0xD10B,0x81);
  LCD_WriteReg(0xD10C,0x00);
  LCD_WriteReg(0xD10D,0xA6);
  LCD_WriteReg(0xD10E,0x00);
  LCD_WriteReg(0xD10F,0xE5);
  LCD_WriteReg(0xD110,0x01);
  LCD_WriteReg(0xD111,0x13);
  LCD_WriteReg(0xD112,0x01);
  LCD_WriteReg(0xD113,0x54);
  LCD_WriteReg(0xD114,0x01);
  LCD_WriteReg(0xD115,0x82);
  LCD_WriteReg(0xD116,0x01);
  LCD_WriteReg(0xD117,0xCA);
  LCD_WriteReg(0xD118,0x02);
  LCD_WriteReg(0xD119,0x00);
  LCD_WriteReg(0xD11A,0x02);
  LCD_WriteReg(0xD11B,0x01);
  LCD_WriteReg(0xD11C,0x02);
  LCD_WriteReg(0xD11D,0x34);
  LCD_WriteReg(0xD11E,0x02);
  LCD_WriteReg(0xD11F,0x67);
  LCD_WriteReg(0xD120,0x02);
  LCD_WriteReg(0xD121,0x84);
  LCD_WriteReg(0xD122,0x02);
  LCD_WriteReg(0xD123,0xA4);
  LCD_WriteReg(0xD124,0x02);
  LCD_WriteReg(0xD125,0xB7);
  LCD_WriteReg(0xD126,0x02);
  LCD_WriteReg(0xD127,0xCF);
  LCD_WriteReg(0xD128,0x02);
  LCD_WriteReg(0xD129,0xDE);
  LCD_WriteReg(0xD12A,0x02);
  LCD_WriteReg(0xD12B,0xF2);
  LCD_WriteReg(0xD12C,0x02);
  LCD_WriteReg(0xD12D,0xFE);
  LCD_WriteReg(0xD12E,0x03);
  LCD_WriteReg(0xD12F,0x10);
  LCD_WriteReg(0xD130,0x03);
  LCD_WriteReg(0xD131,0x33);
  LCD_WriteReg(0xD132,0x03);
  LCD_WriteReg(0xD133,0x6D);
  LCD_WriteReg(0xD200,0x00);
  LCD_WriteReg(0xD201,0x33);
  LCD_WriteReg(0xD202,0x00);
  LCD_WriteReg(0xD203,0x34);
  LCD_WriteReg(0xD204,0x00);
  LCD_WriteReg(0xD205,0x3A);
  LCD_WriteReg(0xD206,0x00);
  LCD_WriteReg(0xD207,0x4A);
  LCD_WriteReg(0xD208,0x00);
  LCD_WriteReg(0xD209,0x5C);
  LCD_WriteReg(0xD20A,0x00);

  LCD_WriteReg(0xD20B,0x81);
  LCD_WriteReg(0xD20C,0x00);
  LCD_WriteReg(0xD20D,0xA6);
  LCD_WriteReg(0xD20E,0x00);
  LCD_WriteReg(0xD20F,0xE5);
  LCD_WriteReg(0xD210,0x01);
  LCD_WriteReg(0xD211,0x13);
  LCD_WriteReg(0xD212,0x01);
  LCD_WriteReg(0xD213,0x54);
  LCD_WriteReg(0xD214,0x01);
  LCD_WriteReg(0xD215,0x82);
  LCD_WriteReg(0xD216,0x01);
  LCD_WriteReg(0xD217,0xCA);
  LCD_WriteReg(0xD218,0x02);
  LCD_WriteReg(0xD219,0x00);
  LCD_WriteReg(0xD21A,0x02);
  LCD_WriteReg(0xD21B,0x01);
  LCD_WriteReg(0xD21C,0x02);
  LCD_WriteReg(0xD21D,0x34);
  LCD_WriteReg(0xD21E,0x02);
  LCD_WriteReg(0xD21F,0x67);
  LCD_WriteReg(0xD220,0x02);
  LCD_WriteReg(0xD221,0x84);
  LCD_WriteReg(0xD222,0x02);
  LCD_WriteReg(0xD223,0xA4);
  LCD_WriteReg(0xD224,0x02);
  LCD_WriteReg(0xD225,0xB7);
  LCD_WriteReg(0xD226,0x02);
  LCD_WriteReg(0xD227,0xCF);
  LCD_WriteReg(0xD228,0x02);
  LCD_WriteReg(0xD229,0xDE);
  LCD_WriteReg(0xD22A,0x02);
  LCD_WriteReg(0xD22B,0xF2);
  LCD_WriteReg(0xD22C,0x02);
  LCD_WriteReg(0xD22D,0xFE);
  LCD_WriteReg(0xD22E,0x03);
  LCD_WriteReg(0xD22F,0x10);
  LCD_WriteReg(0xD230,0x03);
  LCD_WriteReg(0xD231,0x33);
  LCD_WriteReg(0xD232,0x03);
  LCD_WriteReg(0xD233,0x6D);
  LCD_WriteReg(0xD300,0x00);
  LCD_WriteReg(0xD301,0x33);
  LCD_WriteReg(0xD302,0x00);
  LCD_WriteReg(0xD303,0x34);
  LCD_WriteReg(0xD304,0x00);
  LCD_WriteReg(0xD305,0x3A);
  LCD_WriteReg(0xD306,0x00);
  LCD_WriteReg(0xD307,0x4A);
  LCD_WriteReg(0xD308,0x00);
  LCD_WriteReg(0xD309,0x5C);
  LCD_WriteReg(0xD30A,0x00);

  LCD_WriteReg(0xD30B,0x81);
  LCD_WriteReg(0xD30C,0x00);
  LCD_WriteReg(0xD30D,0xA6);
  LCD_WriteReg(0xD30E,0x00);
  LCD_WriteReg(0xD30F,0xE5);
  LCD_WriteReg(0xD310,0x01);
  LCD_WriteReg(0xD311,0x13);
  LCD_WriteReg(0xD312,0x01);
  LCD_WriteReg(0xD313,0x54);
  LCD_WriteReg(0xD314,0x01);
  LCD_WriteReg(0xD315,0x82);
  LCD_WriteReg(0xD316,0x01);
  LCD_WriteReg(0xD317,0xCA);
  LCD_WriteReg(0xD318,0x02);
  LCD_WriteReg(0xD319,0x00);
  LCD_WriteReg(0xD31A,0x02);
  LCD_WriteReg(0xD31B,0x01);
  LCD_WriteReg(0xD31C,0x02);
  LCD_WriteReg(0xD31D,0x34);
  LCD_WriteReg(0xD31E,0x02);
  LCD_WriteReg(0xD31F,0x67);
  LCD_WriteReg(0xD320,0x02);
  LCD_WriteReg(0xD321,0x84);
  LCD_WriteReg(0xD322,0x02);
  LCD_WriteReg(0xD323,0xA4);
  LCD_WriteReg(0xD324,0x02);
  LCD_WriteReg(0xD325,0xB7);
  LCD_WriteReg(0xD326,0x02);
  LCD_WriteReg(0xD327,0xCF);
  LCD_WriteReg(0xD328,0x02);
  LCD_WriteReg(0xD329,0xDE);
  LCD_WriteReg(0xD32A,0x02);
  LCD_WriteReg(0xD32B,0xF2);
  LCD_WriteReg(0xD32C,0x02);
  LCD_WriteReg(0xD32D,0xFE);
  LCD_WriteReg(0xD32E,0x03);
  LCD_WriteReg(0xD32F,0x10);
  LCD_WriteReg(0xD330,0x03);
  LCD_WriteReg(0xD331,0x33);
  LCD_WriteReg(0xD332,0x03);
  LCD_WriteReg(0xD333,0x6D);
  LCD_WriteReg(0xD400,0x00);
  LCD_WriteReg(0xD401,0x33);
  LCD_WriteReg(0xD402,0x00);
  LCD_WriteReg(0xD403,0x34);
  LCD_WriteReg(0xD404,0x00);
  LCD_WriteReg(0xD405,0x3A);
  LCD_WriteReg(0xD406,0x00);
  LCD_WriteReg(0xD407,0x4A);
  LCD_WriteReg(0xD408,0x00);
  LCD_WriteReg(0xD409,0x5C);
  LCD_WriteReg(0xD40A,0x00);
  LCD_WriteReg(0xD40B,0x81);

  LCD_WriteReg(0xD40C,0x00);
  LCD_WriteReg(0xD40D,0xA6);
  LCD_WriteReg(0xD40E,0x00);
  LCD_WriteReg(0xD40F,0xE5);
  LCD_WriteReg(0xD410,0x01);
  LCD_WriteReg(0xD411,0x13);
  LCD_WriteReg(0xD412,0x01);
  LCD_WriteReg(0xD413,0x54);
  LCD_WriteReg(0xD414,0x01);
  LCD_WriteReg(0xD415,0x82);
  LCD_WriteReg(0xD416,0x01);
  LCD_WriteReg(0xD417,0xCA);
  LCD_WriteReg(0xD418,0x02);
  LCD_WriteReg(0xD419,0x00);
  LCD_WriteReg(0xD41A,0x02);
  LCD_WriteReg(0xD41B,0x01);
  LCD_WriteReg(0xD41C,0x02);
  LCD_WriteReg(0xD41D,0x34);
  LCD_WriteReg(0xD41E,0x02);
  LCD_WriteReg(0xD41F,0x67);
  LCD_WriteReg(0xD420,0x02);
  LCD_WriteReg(0xD421,0x84);
  LCD_WriteReg(0xD422,0x02);
  LCD_WriteReg(0xD423,0xA4);
  LCD_WriteReg(0xD424,0x02);
  LCD_WriteReg(0xD425,0xB7);
  LCD_WriteReg(0xD426,0x02);
  LCD_WriteReg(0xD427,0xCF);
  LCD_WriteReg(0xD428,0x02);
  LCD_WriteReg(0xD429,0xDE);
  LCD_WriteReg(0xD42A,0x02);
  LCD_WriteReg(0xD42B,0xF2);
  LCD_WriteReg(0xD42C,0x02);
  LCD_WriteReg(0xD42D,0xFE);
  LCD_WriteReg(0xD42E,0x03);
  LCD_WriteReg(0xD42F,0x10);
  LCD_WriteReg(0xD430,0x03);
  LCD_WriteReg(0xD431,0x33);
  LCD_WriteReg(0xD432,0x03);
  LCD_WriteReg(0xD433,0x6D);
  LCD_WriteReg(0xD500,0x00);
  LCD_WriteReg(0xD501,0x33);
  LCD_WriteReg(0xD502,0x00);
  LCD_WriteReg(0xD503,0x34);
  LCD_WriteReg(0xD504,0x00);
  LCD_WriteReg(0xD505,0x3A);
  LCD_WriteReg(0xD506,0x00);
  LCD_WriteReg(0xD507,0x4A);
  LCD_WriteReg(0xD508,0x00);
  LCD_WriteReg(0xD509,0x5C);
  LCD_WriteReg(0xD50A,0x00);
  LCD_WriteReg(0xD50B,0x81);

  LCD_WriteReg(0xD50C,0x00);
  LCD_WriteReg(0xD50D,0xA6);
  LCD_WriteReg(0xD50E,0x00);
  LCD_WriteReg(0xD50F,0xE5);
  LCD_WriteReg(0xD510,0x01);
  LCD_WriteReg(0xD511,0x13);
  LCD_WriteReg(0xD512,0x01);
  LCD_WriteReg(0xD513,0x54);
  LCD_WriteReg(0xD514,0x01);
  LCD_WriteReg(0xD515,0x82);
  LCD_WriteReg(0xD516,0x01);
  LCD_WriteReg(0xD517,0xCA);
  LCD_WriteReg(0xD518,0x02);
  LCD_WriteReg(0xD519,0x00);
  LCD_WriteReg(0xD51A,0x02);
  LCD_WriteReg(0xD51B,0x01);
  LCD_WriteReg(0xD51C,0x02);
  LCD_WriteReg(0xD51D,0x34);
  LCD_WriteReg(0xD51E,0x02);
  LCD_WriteReg(0xD51F,0x67);
  LCD_WriteReg(0xD520,0x02);
  LCD_WriteReg(0xD521,0x84);
  LCD_WriteReg(0xD522,0x02);
  LCD_WriteReg(0xD523,0xA4);
  LCD_WriteReg(0xD524,0x02);
  LCD_WriteReg(0xD525,0xB7);
  LCD_WriteReg(0xD526,0x02);
  LCD_WriteReg(0xD527,0xCF);
  LCD_WriteReg(0xD528,0x02);
  LCD_WriteReg(0xD529,0xDE);
  LCD_WriteReg(0xD52A,0x02);
  LCD_WriteReg(0xD52B,0xF2);
  LCD_WriteReg(0xD52C,0x02);
  LCD_WriteReg(0xD52D,0xFE);
  LCD_WriteReg(0xD52E,0x03);
  LCD_WriteReg(0xD52F,0x10);
  LCD_WriteReg(0xD530,0x03);
  LCD_WriteReg(0xD531,0x33);
  LCD_WriteReg(0xD532,0x03);
  LCD_WriteReg(0xD533,0x6D);
  LCD_WriteReg(0xD600,0x00);
  LCD_WriteReg(0xD601,0x33);
  LCD_WriteReg(0xD602,0x00);
  LCD_WriteReg(0xD603,0x34);
  LCD_WriteReg(0xD604,0x00);
  LCD_WriteReg(0xD605,0x3A);
  LCD_WriteReg(0xD606,0x00);
  LCD_WriteReg(0xD607,0x4A);
  LCD_WriteReg(0xD608,0x00);
  LCD_WriteReg(0xD609,0x5C);
  LCD_WriteReg(0xD60A,0x00);
  LCD_WriteReg(0xD60B,0x81);

  LCD_WriteReg(0xD60C,0x00);
  LCD_WriteReg(0xD60D,0xA6);
  LCD_WriteReg(0xD60E,0x00);
  LCD_WriteReg(0xD60F,0xE5);
  LCD_WriteReg(0xD610,0x01);
  LCD_WriteReg(0xD611,0x13);
  LCD_WriteReg(0xD612,0x01);
  LCD_WriteReg(0xD613,0x54);
  LCD_WriteReg(0xD614,0x01);
  LCD_WriteReg(0xD615,0x82);
  LCD_WriteReg(0xD616,0x01);
  LCD_WriteReg(0xD617,0xCA);
  LCD_WriteReg(0xD618,0x02);
  LCD_WriteReg(0xD619,0x00);
  LCD_WriteReg(0xD61A,0x02);
  LCD_WriteReg(0xD61B,0x01);
  LCD_WriteReg(0xD61C,0x02);
  LCD_WriteReg(0xD61D,0x34);
  LCD_WriteReg(0xD61E,0x02);
  LCD_WriteReg(0xD61F,0x67);
  LCD_WriteReg(0xD620,0x02);
  LCD_WriteReg(0xD621,0x84);
  LCD_WriteReg(0xD622,0x02);
  LCD_WriteReg(0xD623,0xA4);
  LCD_WriteReg(0xD624,0x02);
  LCD_WriteReg(0xD625,0xB7);
  LCD_WriteReg(0xD626,0x02);
  LCD_WriteReg(0xD627,0xCF);
  LCD_WriteReg(0xD628,0x02);
  LCD_WriteReg(0xD629,0xDE);
  LCD_WriteReg(0xD62A,0x02);
  LCD_WriteReg(0xD62B,0xF2);
  LCD_WriteReg(0xD62C,0x02);
  LCD_WriteReg(0xD62D,0xFE);
  LCD_WriteReg(0xD62E,0x03);
  LCD_WriteReg(0xD62F,0x10);
  LCD_WriteReg(0xD630,0x03);
  LCD_WriteReg(0xD631,0x33);
  LCD_WriteReg(0xD632,0x03);
  LCD_WriteReg(0xD633,0x6D);
  //LV2 Page 0 enable
  LCD_WriteReg(0xF000,0x55);
  LCD_WriteReg(0xF001,0xAA);
  LCD_WriteReg(0xF002,0x52);
  LCD_WriteReg(0xF003,0x08);
  LCD_WriteReg(0xF004,0x00);
  //Display control
  LCD_WriteReg(0xB100, 0xCC);
  LCD_WriteReg(0xB101, 0x00);
  //Source hold time
  LCD_WriteReg(0xB600,0x05);
  //Gate EQ control
  LCD_WriteReg(0xB700,0x70);
  LCD_WriteReg(0xB701,0x70);
  //Source EQ control (Mode 2)
  LCD_WriteReg(0xB800,0x01);
  LCD_WriteReg(0xB801,0x03);
  LCD_WriteReg(0xB802,0x03);
  LCD_WriteReg(0xB803,0x03);
  //Inversion mode (2-dot)
  LCD_WriteReg(0xBC00,0x02);
  LCD_WriteReg(0xBC01,0x00);
  LCD_WriteReg(0xBC02,0x00);
  //Timing control 4H w/ 4-delay
  LCD_WriteReg(0xC900,0xD0);
  LCD_WriteReg(0xC901,0x02);
  LCD_WriteReg(0xC902,0x50);
  LCD_WriteReg(0xC903,0x50);
  LCD_WriteReg(0xC904,0x50);
  LCD_WriteReg(0x3500,0x00);
  LCD_WriteReg(0x3A00,0x55);  //16-bit/pixel
  LCD_WR_COMMAND(0x1100);
  delay_us(120);
  LCD_WR_COMMAND(0x2900);  

#if LCD_DISPLAY_HORIZONTAL
  TFT_Set_Display_Dir(0);//  
#endif
  LCD_BL_HIGH;

    
}

/**
  * @brief  This function is write command to LCD.
  * @param  command : the command to write.
  * @retval None
  */
void LCD_WR_COMMAND(uint16_t command)
{
  *(__IO uint16_t*) XMC_LCD_COMMAND = command;
}

/**
  * @brief  This function is write data to LCD.
  * @param  data : the data to write.
  * @retval None
  */
void LCD_WR_DATA(uint16_t data)
{
  *(__IO uint16_t*) XMC_LCD_DATA = data;
}

uint16_t LCD_RD_DATA(void)
{
  uint16_t data;  
  data = *(__IO uint16_t*) XMC_LCD_DATA;
  return data;
}

/**
  * @brief  This function is set row&column coordinates for LCD.
  * @param  xstart : Row coordinates starting vaule.
  * @param  ystart : column coordinates starting vaule.
  * @param  xend : Row coordinates ending vaule.
  * @param  yend : column coordinates ending vaule.
  * @retval None
  */
void LCD_SetBlock(uint16_t xstart,uint16_t ystart,uint16_t xend,uint16_t yend)
{

		LCD_WR_COMMAND(0X2A00);LCD_WR_DATA(xstart>>8);  
		LCD_WR_COMMAND(0X2A00+1);LCD_WR_DATA(xstart&0XFF);	  
		LCD_WR_COMMAND(0X2A00+2);LCD_WR_DATA(xend>>8);   
		LCD_WR_COMMAND(0X2A00+3);LCD_WR_DATA(xend&0XFF);   
    
		LCD_WR_COMMAND(0X2B00);LCD_WR_DATA(ystart>>8);   
		LCD_WR_COMMAND(0X2B00+1);LCD_WR_DATA(ystart&0XFF);  
		LCD_WR_COMMAND(0X2B00+2);LCD_WR_DATA(yend>>8);   
		LCD_WR_COMMAND(0X2B00+3);LCD_WR_DATA(yend&0XFF); 

    LCD_WR_COMMAND(0x2C00); 

}

/**
  * @brief  This function is write one point to LCD.
  * @param  data : the data to write.
  * @retval None
  */
void LCD_WriteOnePoint(uint16_t color)
{


}

/**
  * @brief  This function is draw point to LCD.
  * @param  data : the data to write.
  * @retval None
  */
void LCD_DrawPoint(uint16_t x,uint16_t y,uint16_t color)
{

  LCD_SetBlock(x,y,x,y);
  
  LCD_WriteOnePoint(color);
}

/**
  * @brief  This function is clear the LCD.
  * @param  data : the data to write.
  * @retval None
  */
void LCD_Clear(uint16_t color)
{
  u32 i; 
  LCD_SetBlock(0,0,800,480);
  for(i=0;i<480*800;i++)
  LCD_WR_DATA(color);
}
