/**
  **************************************************************************
  * @file     xmc_lcd_5510.h
  * @version  v2.0.0
  * @date     2020-11-02
  * @brief    xmc_lcd program header
  **************************************************************************
  *                       Copyright notice & Disclaimer
  *
  * The software Board Support Package (BSP) that is made available to 
  * download from Artery official website is the copyrighted work of Artery. 
  * Artery authorizes customers to use, copy, and distribute the BSP 
  * software and its related documentation for the purpose of design and 
  * development in conjunction with Artery microcontrollers. Use of the 
  * software is governed by this copyright notice and the following disclaimer.
  *
  * THIS SOFTWARE IS PROVIDED ON "AS IS" BASIS WITHOUT WARRANTIES,
  * GUARANTEES OR REPRESENTATIONS OF ANY KIND. ARTERY EXPRESSLY DISCLAIMS,
  * TO THE FULLEST EXTENT PERMITTED BY LAW, ALL EXPRESS, IMPLIED OR
  * STATUTORY OR OTHER WARRANTIES, GUARANTEES OR REPRESENTATIONS,
  * INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT.
  *
  **************************************************************************
  */  
#ifndef __XMC_LCD_5510_H
#define __XMC_LCD_5510_H

#include "at32f403a_407_board.h"

typedef struct
{
  u16 lcd_id;
  void (*xmc_init)(void);
  void (*lcd_init)(void);
  void (*lcd_setblock)(u16 xstart,u16 ystart,u16 xend,u16 yend);
  void (*draw_point)(u16 x,u16 y,u16 color);
  void (*lcd_clear)(u16 color);
}_lcd_dev;

extern _lcd_dev  lcd_dev;
extern _lcd_dev *lcd;

/* The address of write data & command (XMC_A16) */
#define  XMC_LCD_COMMAND    0x6001FFFE
#define  XMC_LCD_DATA       0x60020000
/* The LCD Reset line */
#define LCD_RESET_HIGH  gpio_bits_set(GPIOD,GPIO_PINS_3);
#define LCD_RESET_LOW   gpio_bits_reset(GPIOD,GPIO_PINS_3);

#define LCD_BL_HIGH  gpio_bits_set(GPIOB,GPIO_PINS_0); 
#define LCD_BL_LOW   gpio_bits_reset(GPIOB,GPIO_PINS_0);
static u16 LCD_ID;
#define WHITE         	 0xFFFF
#define BLACK         	 0x0000	  
#define BLUE         	   0x001F  
#define BRED             0XF81F
#define GRED 			       0XFFE0
#define GBLUE			       0X07FF
#define RED           	 0xF800
#define MAGENTA       	 0xF81F
#define GREEN         	 0x07E0
#define CYAN          	 0x7FFF
#define YELLOW        	 0xFFE0
#define BROWN 			     0XBC40
#define BRRED 			     0XFC07
#define GRAY  			     0X8430

//ɨ跽
#define L2R_U2D  0 //,ϵ
#define L2R_D2U  1 //,µ
#define R2L_U2D  2 //ҵ,ϵ
#define R2L_D2U  3 //ҵ,µ

#define U2D_L2R  4 //ϵ,
#define U2D_R2L  5 //ϵ,ҵ
#define D2U_L2R  6 //µ,
#define D2U_R2L  7 //µ,ҵ	 

#define DFT_SCAN_DIR  L2R_U2D  //Ĭϵɨ跽

void xmc_init(void);
void LCD_init(void);
void LCD_WR_COMMAND(u16 command);
void LCD_WR_DATA(u16 data);
u16 LCD_RD_DATA(void);
void LCD_SetBlock(u16 xstart,u16 ystart,u16 xend,u16 yend);
void LCD_WriteOnePoint(u16 color);
void LCD_DrawPoint(u16 x,u16 y,u16 color);
void LCD_Clear(u16 color);
void LCD_WriteReg(u16 LCD_Reg, u16 LCD_RegValue);
void LCD_Set_Scan_Dir(u8 dir);
  
#endif


